@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Converter;
 # ABSTRACT: Classe de base pour convertir les notices
-$Koha::Contrib::Sudoc::Converter::VERSION = '2.21';
+$Koha::Contrib::Sudoc::Converter::VERSION = '2.22';
 use Moose;
 use Modern::Perl;
 
@@ -25,7 +25,8 @@ sub init {
     my $myrcr = $self->sudoc->c->{rcr};
     # On crée la structure de données items
     my $item = {};
-    for my $field ( $record->field('9..') ) {
+    for my $field ( @{$record->fields} ) {
+        next if ref $field eq 'MARC::Moose::Field::Control';
         my $value = $field->subfield('5');
         next unless $value;
         my ($rcr, $id) = $value =~ /(.*):(.*)/;
@@ -199,7 +200,7 @@ Koha::Contrib::Sudoc::Converter - Classe de base pour convertir les notices
 
 =head1 VERSION
 
-version 2.21
+version 2.22
 
 =head1 DESCRIPTION
 
